@@ -12,7 +12,7 @@
 /*                                                                      */
 /************************************************************************/
 
-// $Id: CoinMP.cpp 567 2013-11-29 10:49:26Z bjarni $
+// $Id: CoinMP.cpp 581 2013-11-30 21:47:17Z bjarni $
 
 #include <stdlib.h>
 #include <string.h>
@@ -27,7 +27,6 @@
 
 #include "CoinCbc.h"
 
-
 #include "config_coinmp_default.h"
 
 
@@ -36,22 +35,11 @@
 #include "CoinMP.h"
 
 
-#if COINMP_VERSION_MAJOR == 9999
-const char*  COINMP_VERSIONSTR = "1.7";
-const int    COINMP_VERSIONINT = 170;
-const double COINMP_VERSIONDBL = 1.70;
-#else
-const char*  COINMP_VERSIONSTR = COINMP_VERSION;
-# if COINMP_VERSION_RELEASE == 9999
-const int    COINMP_VERSIONINT = (COINMP_VERSION_MAJOR * 100 + COINMP_VERSION_MINOR * 10);
-const double COINMP_VERSIONDBL = (COINMP_VERSION_MAJOR + COINMP_VERSION_MINOR / 10.0);
-# else
-const int    COINMP_VERSIONINT = (COINMP_VERSION_MAJOR * 100 + COINMP_VERSION_MINOR * 10 + COINMP_VERSION_RELEASE);
-const double COINMP_VERSIONDBL = (COINMP_VERSION_MAJOR + COINMP_VERSION_MINOR / 10.0 + COINMP_VERSION_RELEASE / 100.0);
-# endif
-#endif
+const char*  COINMP_VERSIONSTR = "1.7.6";
+const int    COINMP_VERSIONINT = 176;
+const double COINMP_VERSIONDBL = 1.76;
 
-const char*  COINMP_NAME       = "CoinMP";
+const char* COINMP_NAME = "CoinMP";
 
 
 /************************************************************************/
@@ -112,7 +100,7 @@ SOLVAPI double SOLVCALL CoinGetVersion(void)
 SOLVAPI int SOLVCALL CoinGetFeatures(void)
 {
 	return SOLV_FEATURE_LP |
-			SOLV_FEATURE_MIP;
+		   SOLV_FEATURE_MIP;
 }
 
 
